@@ -1,7 +1,7 @@
 package Yukki::Web::Context;
-$Yukki::Web::Context::VERSION = '0.991_004'; # TRIAL
+$Yukki::Web::Context::VERSION = '0.991_005'; # TRIAL
 
-$Yukki::Web::Context::VERSION = '0.991004';use v5.24;
+$Yukki::Web::Context::VERSION = '0.991005';use v5.24;
 use utf8;
 use Moo;
 
@@ -9,6 +9,7 @@ use Sub::Name qw( subname );
 use Type::Utils;
 use Types::Standard qw( ArrayRef HashRef Str );
 use Types::URI qw( Uri );
+use URI;
 use Yukki::Web::Request;
 use Yukki::Web::Response;
 
@@ -82,7 +83,7 @@ sub _build_base_url {
     }
 
     else {
-        return $_;
+        return URI->new($base_url);
     }
 }
 
@@ -136,7 +137,7 @@ Yukki::Web::Context - request-response context descriptor
 
 =head1 VERSION
 
-version 0.991_004
+version 0.991_005
 
 =head1 SYNOPSIS
 
